#
# spec file for package iprutils
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define vmajor 2
%define vminor 4
%define vpatch 19
%define tag rel-%{vmajor}-%{vminor}-%{vpatch}
Name:           iprutils
VCS: https://src.suse.de/SLFO-pool/iprutils#91951f38d1dbb02105a3a1c240e06321a52215cc2ef9adcc5f398e4563dad3a8
# NOTE: package's changelog is hidden in % changelog section
# in file iprutils/spec/iprutils.spec
Version:        %{vmajor}.%{vminor}.%{vpatch}
Release:        160000.1.6
Summary:        Utilities for the IBM Power Linux RAID Adapters
License:        CPL-1.0
Group:          Hardware/Other
URL:            https://github.com/bjking1/iprutils/releases
Source:         https://github.com/bjking1/iprutils/archive/%{tag}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(glib-2.0)
ExclusiveArch:  ppc ppc64 ppc64le
%systemd_requires
%if 0%{?suse_version} > 1320
BuildRequires:  pkgconfig(form)
BuildRequires:  pkgconfig(ncurses)
%else
BuildRequires:  ncurses-devel
%endif

%description
Provides a suite of utilities to manage and configure SCSI devices
supported by the ipr SCSI storage device driver.

%prep
%setup -q -n %{name}-%{tag}

%build
export CPPFLAGS="$(pkg-config ncurses form --cflags)"
export LIBS="$(pkg-config ncurses form --libs)"
source ./bootstrap.sh
autoreconf
%configure --sbindir=%{_sbindir} --libdir=%{_libdir} --disable-static
make %{?_smp_mflags}

%install
%make_install
ln -s service %{buildroot}%{_sbindir}/rciprdump
ln -s service %{buildroot}%{_sbindir}/rciprinit
ln -s service %{buildroot}%{_sbindir}/rciprupdate

%pre
%service_add_pre iprdump.service
%service_add_pre iprinit.service
%service_add_pre iprupdate.service

%post
%service_add_post iprdump.service
%service_add_post iprinit.service
%service_add_post iprupdate.service

%preun
%service_del_preun iprdump.service
%service_del_preun iprinit.service
%service_del_preun iprupdate.service

%postun
%service_del_postun iprdump.service
%service_del_postun iprinit.service
%service_del_postun iprupdate.service

%files
%license LICENSE
%doc README
%{_sbindir}/iprconfig
%{_sbindir}/iprdump
%{_sbindir}/iprupdate
%{_sbindir}/iprinit
%{_sbindir}/iprdbg
%{_sbindir}/iprsos
%{_mandir}/man8/*
%{_sysconfdir}/ha.d
%{_sysconfdir}/ha.d/resource.d
%{_sysconfdir}/ha.d/resource.d/iprha
%{_sysconfdir}/bash_completion.d/*
%{_unitdir}/*
%{_sbindir}/rciprdump
%{_sbindir}/rciprinit
%{_sbindir}/rciprupdate
%{_udevrulesdir}/*

%changelog
* Mon Aug 10 2020 msuchanek@suse.de
- version update to 2.4.19 (jsc#SLE-13632)
  - Fixup format_req to no always return true
  - Fix quoting of ncurses flags
  - Free the raid_cmd_head list before creating the raid menu
  - fix iprdump sigserv on non-existing dump file
  - Add support for descriptor format sense data
- remove upstreamed patches
  - iprutils.fix_ncurses_cflags_var.patch
  - bsc1165878-free-raid-cmd-head-list.patch
- update project URL.
* Tue Apr 21 2020 josef.moellers@suse.com
- Without freeing the raid_cmd_head list before creating the raid menu,
  GUI menu of creating/deleting an array got mess up.
  Free the raid_cmd_head list before creating the raid menu
  [bsc#1165878, bsc1165878-free-raid-cmd-head-list.patch]
* Thu Jun  6 2019 josef.moellers@suse.com
- version update to 2.4.18
  - Fix format for RAID hang
  - Fix driver unbind on format
  [jsc#SLE-6586, bsc#1137455]
* Wed Oct 31 2018 msuchanek@suse.com
- version update to 2.4.17 (fate#326435, jsc#SLE-6586)
  - Further show-details speedup
  - Use udev activation
- refreshed iprutils.fix_ncurses_cflags_var.patch
- fix license warning
* Tue May 29 2018 jloeser@suse.com
- version update to 2.4.16 (fate#325179)
  - Speedup for show-details
  - Improve error messages when creating the arrays with RI and non-RI disks
  - Fix download microcode to all devices
  - Fix microcode image sorting on little endian systems
- removed patches:
  * iprutils-Fix-download-microcode-to-all-devices.patch
  * iprutils-Fix-microcode-image-sorting-on-little-endian-systems.patch
* Tue Feb 27 2018 msuchanek@suse.com
- Fix microcode download (bsc#1082712) (bsc#1081558)
  + iprutils-Fix-download-microcode-to-all-devices.patch
  + iprutils-Fix-microcode-image-sorting-on-little-endian-systems.patch
* Wed Oct 18 2017 msuchanek@suse.com
- Update to upstream 2.4.15 (fate#322236)
  - Enable write cache policy for JBODs
  - Fix data direction for some SG_IO ioctls
  - improve README documentation
  - Display RAID migration status (bsc#1064001)
  - Add reserved bits in page 2 of ses device
- Make buildable in Leap42
- Fix dangling service symlinks
- Run throuthg spec-cleaner
* Wed Mar  1 2017 jloeser@suse.com
- version update to 2.4.14 (fate#321592)
  - Remove sleeps from iprconfig initialization
  - Filter out JBOD HDDs from the device statistics menu
  - Allow VSET write cache in bare metal mode
  - Fix raid-create on dual adapter setups
  - Wait for sg module
  - Disable rebuild verify by default for single adapter configurations
  - Remove stale debug printf
  - Vset cache enable fixes
  - Backwards compatibility for endian swapped device_id
  - Fix iprconfig dump option to log full IOA details
* Tue Feb  7 2017 werner@suse.de
- Export LIBS and not LDFLAGS
- Switch over to ncurses ABI 6
* Mon Feb  6 2017 werner@suse.de
- Require pkgconfig form5 and ncurses5 for build
* Tue Aug 23 2016 jloeser@suse.com
- version update to 2.4.13 (bsc#994964)
  - Additional fixes for tracking known zeroed state
* Fri Aug  5 2016 rw@suse.com
- version update to 2.4.12 (FATE#319567, bsc#992141)
  - Display higher link rates in path details
  - Flush unused multipaths prior to array delete
  - Collect additional logs with iprsos
  - Display sr device name
  - Fix format timeout issue on little endian systems
  - Format timeout and format block size fixes
  - Remove unnecessary iprconfig prompt on exit
  - Save known zeroed state for command line format
  - Fix find_multipath_jbod to never return itself
  - Ensure device known zeroed state gets saved after format
  - Fix for hotplug disk with Slider drawer
* Thu Apr 14 2016 jloeser@suse.com
- cleanup spec file
* Thu Apr  7 2016 jloeser@suse.com
- version update to 2.4.11 (FATE#319567)
  - see Changelog under iprutils-rel-2-4-11/spec/iprutils.spec
- modified patches:
  * iprutils.fix_ncurses_cflags_var.patch
- removed patches:
  * iprutils.nososreport.patch
* Tue Oct 27 2015 dvaleev@suse.com
- Update to 2.4.9
  - Add support for sync cache managed array write cache on supported adapters
  - Add supportconfig plugin
  - Misc build cleanups and fixes
  - Microcode download UI enhancements
  - Add new show-ucode-levels to list all microcode levels for all ipr devices
  - Add support to change rebuild rate from ncurses
- Don't enable sosreport by default (iprutils.nososreport.patch)
- Drop python from BuildRequires
- Spec file cleanup
- Specify explicitly systemd unitdir, upstream is buggy here.
* Fri Oct 23 2015 dvaleev@suse.com
- Build only for Power architectures. IPR adapters are mainly
  presented there.
* Thu Oct 22 2015 dvaleev@suse.com
- Don't package sos report plugin (bsc#951575)
* Fri Jul 24 2015 jloeser@suse.com
- version update to 2.4.8 (FATE#317991)
  - see Changelog under iprutils-2.4.8/spec/iprutils.spec
  - to prevent failing configure, fetch all cflags
  - do not stop ipr daemons when reading sysfs fails (bsc#930695)
- added patches:
  * iprutils.fix_ncurses_cflags_var.patch
- removed patches:
  * iprconfig.usr-sbin.patch
  * iprutils-close.diff
  * iprutils.bug-896587_mig_fix_le.patch
  * iprutils.bug-908952_show_disks_and_pyhiscal_location.patch
  * iprutils.bug-923181_fix_create_raid_level.patch
  * iprutils.generate_ipr_dump_file.patch
  * iprutils.install-man.patch
  * iprutils.read_intensive_disks_doesnt_show_up.patch
  * iprutils.redundant_paths_in_GTO.patch
  * iprutils.runlevel.patch
* Wed Apr  8 2015 jloeser@suse.com
- fix create raid level (bsc#923181)
- added patches:
  * iprutils.bug-923181_fix_create_raid_level.patch
* Mon Feb  2 2015 jloeser@suse.com
- fix for showing up disks/platform locations (bsc#908952)
- added patches:
  * iprutils.bug-908952_show_disks_and_pyhiscal_location.patch
* Wed Sep 17 2014 stefan.fent@suse.com
- Add patch to fix migration between Raid levels 0 & 10
  (bnc 896587) (iprutils.bug-896587_mig_fix_le.patch)
* Wed Aug 27 2014 jloeser@suse.com
- "read intensive" disks are now showing up in iprconfig menu
  (bnc#890872)
- added patches:
  * iprutils.read_intensive_disks_doesnt_show_up.patch
* Thu Jul  3 2014 meissner@suse.com
- add %%systemd_requires to ensure correct installation order
  bnc#877576
* Tue May 27 2014 meissner@suse.com
- make the %%pre/%%post sections unconditional. bnc#877576
* Wed May 14 2014 meissner@suse.com
- also add the %%pre snippets for service addition.
* Wed May  7 2014 jloeser@suse.com
- iprutils does not require libsysfs as dependency anymore
  (BNC#876661)
* Tue May  6 2014 jloeser@suse.com
- fix generation of ipr dump file (BNC#876235)
- fix for GTO dual configuration in query-path-status (BNC#876236)
- added patches:
  * iprutils.generate_ipr_dump_file.patch
  * iprutils.redundant_paths_in_GTO.patch
* Fri Apr 11 2014 jloeser@suse.com
- version update to 2.4.1 (BNC#870888)
  - remove iprutils.firmware_level.patch,
    iprutils.failing_raid-create.patch
  - fix seg faults when trying to check the properties of missing
    disk
  - switch to systemd: added iprdump.service, iprinit.service,
    iprupdate.service
* Thu Mar 13 2014 jloeser@suse.com
- new patch: iprutils.failing_raid-create.patch
    fix for raid-create when creating raid for dual adapter mode
    (BNC#868032)
* Wed Mar 12 2014 jloeser@suse.com
- new patch: iprutils.firmware_level.patch
    fix for firmware level showed as "FFFFFFF" (BNC#867744)
* Thu Feb 13 2014 jloeser@suse.com
- version update to 2.4.0 (bnc#860283, bnc#862958)
  - fixing several bugs on LE system
  - remove libsysfs dependency
* Fri Jan 10 2014 jloeser@suse.com
- version update to 2.3.16 (FATE#315573)
  - Support for SAS concurrent maintenance
  - Adds support for new Crocodile based SAS adapters on x86
  - Latest Fixes
* Mon Dec  9 2013 dvaleev@suse.com
- build on ppc64le
* Thu Jul  4 2013 dvaleev@suse.com
- Release 2.3.15
  - Add support for 4K bytes/sector disks in iprutils
- Release 2.3.14
  - Fixes stale information after hot plug a disk into an array
  - Segmentation fault when removing a disk with hot spare disk
  - Fxied sysfs error when updating microcode
  - Fixes the platform location issue for Tres drawer
  - Fix hop count defines
* Wed Jan 16 2013 dvaleev@suse.com
- update to 2.3.13
  - Fixes Platform Location for 32bit adapter.
  - Adds support for optical devices.
  - Fixes platform location for disks.
  - Addes supporting suspend/resume utility for BlueHawk.
  - Fixes raid array delete error.
  - Fixes deleting an array logs I/O errors.
  - Fixes buffer overflow in disk details.
  - Fixes wrong status on an array for the secondary controller.
  - Fixes add_string_to_body() for non-interactive interface.
  - Fixes IOA asymmetric access mode change.
  - Gets location code when SES page 4 is unavailable.
  - Fixes physical location error if disk is vses disk.
* Tue May 15 2012 jloeser@suse.com
- update to version 2.3.10
- clean up spec file
* Tue Mar 20 2012 vcizek@suse.com
- update to 2.3.9
  dropped iprutils-noswab.patch (merged upstream)
  Long time no update, so many changes:
  - Adds support for FPGA updates.
  - Only uses primary adapter for initialize and format disk task.
  - Fixes segmentation fault when qac is not available.
  - Increases maximum dump size.
  - Adds initial support for sis64 asymmetric access changes.
  - Fixes segmentation faults when trying to display certain information.
  - Fixes code incompatibility with libsysfs version 1.
  - Adds Resource Path display for SIS64 devices.
  - Adds support for the new live dump functionality.
  - Fixes battery info for little endian architectures.
  - Fixes buffer overflow when the SCSI Host ID is equal or greater than 1000.
  - Fixes firmware image files left open after getting firmware level.
  - Changes IOA DRAM size display from hex to decimal base.
  - Handles SG_IO ioctl error with older distros which caused disk microcode
    download to fail with JBOD's.
  - Fixes platform location display on blades.
  - Fixes the Platform Location Information display for hotplug adapters and
    displays the information for non-hotplug adapters.
  - Fixes a NULL pointer dereference which caused the daemons to silently fail.
  - Fixes several potential memory leak problems.
  - Add support for SSD drives.
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Wed Oct  6 2010 aj@suse.de
- Fix building of 11.3 in devel project
* Tue Sep  7 2010 aj@suse.de
- BuildRequire sysfsutils-devel
* Wed Oct 14 2009 stefan.fent@novell.com
- add iprutils-close.diff (bnc #543987, bnc #534914)
* Tue Mar 10 2009 ro@suse.de
- do not try to include <linux/byteorder/swab.h>
* Tue Nov 18 2008 olh@suse.de
- update iprutils to version 2.2.13 (bnc#443674 - LTC49827)
  Additional fixes for the active-active functionality.
  Fixes for iprdump to recognize a /sys/devices path.
* Tue Oct 28 2008 olh@suse.de
- update iprutils to version 2.2.12 (bnc#435552 - LTC48936)
  Additional GUI support and fixes for the active-active functionality.
  Fixes for CLI RAID create and delete.
* Mon Sep 29 2008 olh@suse.de
- update iprutils to version 2.2.11 (bnc#417522 - FATE#304156 - LTC47076)
  Add support for the active-active functionality.
* Fri Aug 29 2008 olh@suse.de
- fix an uninitialized but unused variable
- move defines in iprlib.h out of bigendian section
* Wed Aug 27 2008 olh@suse.de
- add /usr/include/ncurses to CFLAGS
* Wed Aug 27 2008 olh@suse.de
- update iprutils to version 2.2.10
  Add support for the array migration functionality.
* Mon Apr 21 2008 olh@suse.de
- add fillup_prereq
* Mon Apr 21 2008 olh@suse.de
- update iprutils to version 2.2.9 (bnc#375379 - LTC43583)
  Do not save preferred primary attribute to fix an infinite failover
  problem in HA two system RAID configuration.
* Mon Nov  5 2007 sassmann@suse.de
- fix init script dependencies
* Tue Oct 23 2007 sassmann@suse.de
- update iprutils to version 2.2.8 (fate #302728)
  Update iprutil to support the PCI-E SAS RAID and non-RAID
  adapters on power6
* Wed Jun 20 2007 olh@suse.de
- update to version 2.2.6 (141618 – LTC20388)
  Fix iprinit dual initiator failover device rescanning code.
  Add iprha init.d script to enable/disable primary adapter mode
  for dual initiator configs.
  Add adapter config option in iprconfig for setting primary/secondary
  adapter in dual adapter environment.
  Add iprconfig option to display SAS dual pathing information.
  Increase time waiting for new devices to show up in
  iprconfig when doing concurrent add.
  Add filename date to microcode download screen. (Ryan Hong)
  Fix to prevent unnecessarily writing sysfs attributes. (Ryan Hong)
  Return standard error code according to send_dev_init() return code.
  Fix incorrect memory free in analyze log menus.
* Thu Mar 29 2007 olh@suse.de
- add ncurses-devel to buildrequires
* Sun Feb  4 2007 olh@suse.de
- update to version 2.2.4
  Fix send diagnostics buffer transfer length to be only what was
  received in the receive diagnostics. Fixes disk hotplug on
  some SAS disk enclosures.
  Sourceforge patch 1627673: iprutils fix to buffer overflow
  Add checking to iprconfig command "set-qdepth" input queue
  depth value. If the given value is larger than 255, fail the command.
  Fix a bug in which the iprconfig command "raid-create"
  may create an illegal queue depth value to the ipr
  config file.
  Sourceforge patch 1627672: iprutils fix to buffer overflow
  Fix a bug in which the iprconfig command "raid-create"
  may create an illegal queue depth value to the ipr
  config file.
  Fixes for SES microcode download on SAS.
  Change to handle UA responses in the JBOD iprinit sequence.
  Fix segfault in iprconfig if /var/log does not exist.
  Allow IOA microcode download to a secondary IOA.
  Fix to prevent errors during SAS SES microcode download.
  Add a couple utility functions for SAS
    ipr_query_sas_expander_info
    ipr_query_res_redundancy_info
* Thu Dec  7 2006 olh@suse.de
- fix comparison with string literal warning (226402)
* Wed Nov 15 2006 olh@suse.de
- update to version 2.2.3 (218770 - LTC28528 - FATE301562)
  Fix SAS disk hotplug dual path bug.
  Change default QERR setting for SAS to 0.
* Fri Nov 10 2006 olh@suse.de
- fix man page permissions
* Fri Sep 22 2006 olh@suse.de
- update to version 2.2.3
  Fix iprconfig set-format-timeout.
  Reduce default JBOD queue depth to 3.
  Fix iprconfig -c set-bus-speed.
  Fix a race condition with hotplug events which could
  cause the ipr daemons to run before newly added devices
  are completed added to the system.
  Fix a segfault in iprdbg when using the macro function
* Tue Aug 15 2006 olh@suse.de
- update to version 2.2.0
  Fix for command line SES microcode update.
  Use IOA's default format timeout for AF DASD instead
  of using a hard coded default.
  Add support to iprinit for it to handle disks going
  from JBOD <-> AF format across an adapter reset. When this
  is detected, iprinit will now attempt to delete the disk
  and then rescan that slot.
  Fixed an ncurses screen drawing bug which resulted in the
  screen getting paged down if the cursor was on the last item
  on the screen and 't' was pressed to toggle the display.
  Added disk concurrent maintenance support for handling
  dual pathed SAS disks.
  Improve iprdbg's logging
  Print better status for devices when IOA is offline/dead.
* Wed Jul 19 2006 olh@suse.de
- update to version 2.1.5
  Fix to allow for compiling with libsysfs 2.0.0
  Remove RAID support for some older drives that should never
  have been supported.
* Tue Mar 14 2006 olh@suse.de
- update to version 2.1.4 (#153800 - LTC22056)
  Concurrent maintenance fix for certain iSeries
  enclosures which would result in non existent
  drive slots being displayed in iprconfig.
  Remove some redundant code in disk hotplug path
  Fixup status of RAID 10 arrays to print a better status
  under multiple failure scenarios.
* Mon Feb 27 2006 olh@suse.de
- update to version 2.1.3 (#153800 - LTC22056)
  Prevent duplicate mode sense commands from being issued.
  More uevent handling improvements.
  Automatically create hotplug directory if it doesn't
  already exist so adapter microcode update works.
  Improve robustness of uevents failure handling. Fall
  back to polling method if needed.
  Auxiliary cache adapter fixes.
  Fix iprconfig -c update-ucode to properly report an
  error if the wrong microcode level is specified.
  Fixed a compiler issue.
  Fixed a bug in iprconfig query-raid-create that prevented
  JBOD candidates from being displayed if there were no
  AF candidates as well.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 olh@suse.de
- update to version 2.1.2 (#142149 - LTC20569)
  Make iprupdate return success/failure indication when invoked with --force.
  Concurrent maintenance fix for 7031-D24/T24.
* Tue Dec 20 2005 olh@suse.de
- update to version 2.1.1 (#140106 - LTC20386)
  Fix compile error in iprconfig
* Mon Dec 19 2005 olh@suse.de
- update to version 2.1.0 (#140106 - LTC20386)
  - Updates for aux cache IOAs
  - Updates for SAS adapters
  - Misc fixes for new iprconfig command line options
  - Add command line options to iprconfig to perform virtually
    every iprconfig function available in the ncurses interface.
* Thu Nov 17 2005 olh@suse.de
- update to version 2.0.15.6 (#134205 - LTC19786)
  - Fix concurrent maintenance with disk drawers reporting
  multiple SES devices on the same SCSI bus.
* Tue Nov 15 2005 uli@suse.de
- enabled for ARM
* Wed Oct 19 2005 olh@suse.de
- update to version 2.0.15.5 (#129140 - LTC19043)
  - Don't show enclosures in list of devices to remove in
  concurrent remove screens of iprconfig.
  - Fix concurrent disk remove function in iprconfig for
  certain disk enclosures.
  - Fix string length calculation in ipr_get_hotplug_dir
* Mon Sep  5 2005 olh@suse.de
- keep iprconfig in /sbin in SLES9 builds
* Mon Sep  5 2005 olh@suse.de
- update to version 2.0.15.4
  correct fix for a couple of uninitialized variable compile errors
* Sat Aug 20 2005 olh@suse.de
- update to version 2.0.15.3 (#105892 - LTC17555)
  Fix: iprconfig: IOA microcode update would leave AF DASD
  (disks that are in disk arrays) in a state where they were
  no longer tagged queueing. Fix iprconfig to run iprinit on the
  adapter after a microcode download to ensure all attached devices
  are properly setup after a microcode download.
  Fix iprinit: If an IOA was reset for some reason at runtime,
  this would cause AF DASD devices to get tagged queueing turned
  off and it would never get turned back on. Change iprinit to
  detect this and turn tagged queueing back on if this happens.
  Changing the queue depth for a disk array was broken. Fix iprinit
  to properly restore the queue depth from the ipr configuration file.
  Fix iprconfig to handle disk format failures better
  Fix potential iprutils segfaults when iterating over disk arrays
  Fix: iprconfig: Concurrent remove/add of disks would display
  the same slot multiple times on some hardware due to SES devices
  returning bogus data. Work around this by only not showing duplicate
  slots.
  Fix: iprconfig: including a disk to a RAID 5 array when multiple
  RAID 5 arrays were attached would sometimes cause the disk
  to get included into the wrong array.
* Fri Jul  1 2005 olh@suse.de
- fix uninitalized variables, use RPM_OPT_FLAGS
* Fri Jun 24 2005 olh@suse.de
- iprconfig links agains libs in /usr, move it to /usr/sbin
* Mon Jun 13 2005 olh@suse.de
- sysfsutils was split from udev
* Thu Jun  2 2005 olh@suse.de
- update to version 2.0.15.1 (#86744 - LTC16252)
  Fix iprconfig Analyze Log options
* Fri May 20 2005 olh@suse.de
- update to version 2.0.15 (#84694 - LTC16058)
  Clarify format options
  Setup mode page 0 for IBM drives to ensure command aging is
  enabled. This ensures commands are not starved on some drives.
  Fix so that iprdump properly names dump files once 100 dumps
  have been made.
  Make iprconfig handle failures of scsi disk formats better
  Fix iprconfig Set root kernel message log directory menu
  Properly display RAID level on all iprconfig screens
  Don't disable init.d daemons on an rpm -U
  Add ability to force RAID consistency check
* Fri Apr 15 2005 pkirsch@suse.de
- update to version 2.0.14.2 (#77450 - LTC15108)
  Fixed bug preventing disk microcode update from working.
  Removed mention of primary/secondary adapters in some error
  screens since multi-initiator RAID is not supported and the
  messages will just cause confusion.
  iprconfig: During disk hotplug, wait for sd devices to show
  up. Fixes errors getting logged by iprconfig during hotplug.
  iprconfig: Fix cancel path on concurrent add/remove of disks
  Don't display current bus width and speed for SAS disks
  Fix scoping bug caught by gcc 4.0.
  Stop iprupdate from continually logging errors for adapters with
  backlevel adapter firmware.
* Tue Mar 22 2005 olh@suse.de
- remove requirement from libcap
* Sat Mar 19 2005 olh@suse.de
- update to version 2.0.14 (#72125 - LTC14443)
  Add support for non-interactive array creation and deletion through
  iprconfig.
  Use kobject_uevent notifications instead of polling if the kernel
  supports it.
  Fix iprconfig to set the actual queue depth for advanced function disks
  Allow user to force tagged queuing on to drives that do not support
  QERR=1.
  iprconfig: Download microcode. Fix blank screen when displaying
  lots of microcode images.
  Add "known to be zeroed" tracking to iprconfig to drastically reduce the
  time required to create a RAID array when starting with 512 formatted disks
  Add ability to query multi-adapter status for dual initiator RAID configs
  Add ability to set "preferred primary" adapter when running dual initiator RAID configs
  Add iprconfig screen to display dual adapter status for dual initiator RAID configs
  Prevent RAID configuration from occurring on "secondary" adapter in dual initiator RAID configs
  Use /dev/sd for SG_IO instead of /dev/sg when possible
  Set QERR=3 rather than 1 for multi-initiator configurations
  Set TST=1 for multi-initiator configurations
  Allow Format device for JBOD function to work for JBOD adapters
  Fix handling of dead adapters in all of iprutils.
* Sat Feb 26 2005 olh@suse.de
- update to version 2.0.13.7 (#63874 - LTC12818)
  Fix to support multiple firmware dirs in /etc/hotplug/firmware.agent
  Fix use of uninitialized variable in iprconfig.
  Fix handling of medium format corrupt drives for drives
  that return NOT_READY instead of MEDIUM_ERROR.
  Fix iprconfig RAID start bug for systems with multiple RAID adapters.
  Fix iprconfig RAID include bug for systems with multiple RAID adapters.
  Fix failing array add device due to race condition with iprinit.
  Fix iprconfig microcode download to ipr adapters.
* Tue Oct 26 2004 olh@suse.de
- update to version 2.0.13.1 (#47633 - LTC12054)
  Fix iprinit to wait for scsi generic devices to show up in case
  we are racing with hotplug. Fixes the following error:
    0:255:0:0: Mode Sense failed. rc=1, SK: 5 ASC: 24 ASCQ: 0
* Mon Oct 11 2004 olh@suse.de
- update to version 2.0.13 (#47039 - LTC11719)
  - Improve iprupdate error logs to indicate where to download microcode from.
  - Set default tcq queue depth for AS400 disks to 16.
  - Don't log errors in iprdump if CONFIG_IPR_DUMP not enabled in the kernel
  - Fix sysfs parsing to handle new sdev target kernel change
  - Rescan JBOD devices following recovery format to make the device
    usable if it was originally in an unsupported sector size.
  - Display correct adapter serial number in iprconfig.
  - Support for microcode download to new adapters.
  - Support for iSeries disk microcode update using microcode images
    from the pSeries microcode website.
* Fri Jun 11 2004 meissner@suse.de
- update to version 2.0.12
  - Fix bug preventing ucode download to iSeries disks from working.
    LTC#9303/#41935
* Fri Jun 11 2004 meissner@suse.de
- update to version 2.0.11
  - Fix segmentation fault in _sg_ioctl that was causing a silent
    failure of microcode update to disks. The microcode update would
    fail, but no error would be logged. The seg fault was in a child
    process, so the parent process kept running. #41905/LTC#9265
* Sun May 23 2004 olh@suse.de
- update to version 2.0.10
  - Don't let iprdbg sg ioctls be retried. (#41045 - LTC8812)
  - Add --force flag to iprconfig to allow user to workaround buggy
    drive firmware. (#41043 - LTC8810)
  - Don't initialize read/write protected disks (#41044 - LTC8811)
  - Fix some reclaim cache bugs (#41042 - LTC8809)
  - Don't setup Mode Page 0x0A if test unit ready fails
    (#41041 - LTC8808)
* Mon May  3 2004 olh@suse.de
- update to version 2.0.9
  - Add --debug option to all utilities
  - Make utilities behave better when ipr is not loaded
  - Fix dependencies in init.d scripts
  - Don't log an error if ipr is not loaded
* Thu Apr 29 2004 olh@suse.de
- update to version 2.0.8
  - Fix memory leak in code download path
  - Increase size of page 0 inquiry buffer so that extended vpd is
    displayed
  - Decrease write buffer timeout to 2 minutes
  enable rcscripts iprdump, iprinit, iprupdate per default on ppc
  (#39612 - LTC7898)
* Fri Apr 16 2004 olh@suse.de
- update to version 2.0.7
  - Load sg module in init.d scripts if not loaded
  - Load sg module in iprconfig if not loaded
* Thu Apr 15 2004 olh@suse.de
- update to version 2.0.6
  - Battery maintenance fixes.
  - Fix to properly display failed status for pulled physical disks.
  - Battery maintenance fixes.
  - Fix init.d scripts to work properly with yast runlevel editor.
  - Fix device details screen in iprconfig for Failed array members
  - Allow formatting devices even if qerr cannot be disabled
* Tue Mar 30 2004 olh@suse.de
- update to version 2.0.4
* Fri Mar 19 2004 olh@suse.de
- do not enable daemons per default, needs a different solution
* Sun Mar 14 2004 olh@suse.de
- initial package with version 2.0.2
